@@ -3,14 +3,14 @@
 #' @description
 #' In order to use a function as a tool in a chat, you need to craft the right
 #' call to [tool()]. This function helps you do that for documented functions by
-#' extracting the function's R documentation and creating a `tool()` call for
-#' you, using an LLM. It's meant to be used interactively while writing your
+#' extracting the function's R documentation and using an LLM to generate the
+#' `tool()` call. It's meant to be used interactively while writing your
 #' code, not as part of your final code.
 #'
 #' If the function has package documentation, that will be used. Otherwise, if
 #' the source code of the function can be automatically detected, then the
 #' comments immediately preceding the function are used (especially helpful if
-#' those are Roxygen comments). If neither are available, then just the function
+#' those are roxygen2 comments). If neither are available, then just the function
 #' signature is used.
 #'
 #' Note that this function is inherently imperfect. It can't handle all possible
@@ -108,11 +108,9 @@ create_tool_def <- function(
 
   topic_str <- format(expr)
 
-  payload <- paste0(
-    "Function name: ",
-    topic_str,
-    "\n\nFunction documentation:\n\n",
-    help_text
+  payload <- paste_c(
+    c("<name>", topic_str, "</name>\n\n"),
+    c("<documentation>\n", help_text, "</documentation>\n\n")
   )
 
   if (isTRUE(verbose)) {
@@ -206,7 +204,6 @@ extract_comments_and_signature <- function(func) {
   }
 
   start_line <- src[1]
-  end_line <- src[3]
   comments <- extract_comments(filename, start_line)
   if (is.null(comments)) {
     return(sig)
